# PiDotLCD
Python driver for using a 128x64 dot LCD display on a Raspberry Pi

## Basic Usage
```python3
import PiDotLCD

# Create display
display = PiDotLCD.display()

display.set_pixel(16, 16) # Set pixel

display.set_pixel(16, 16, False) # Clear pixel
```
